<?php
 
/**
 * @file
 * Contains \Drupal\field_content_access\Form\RedirectPathForm.
 */
 
namespace Drupal\field_content_access\Form;

use Drupal\system\Form;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Path\AliasManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Path\PathValidatorInterface;
use Drupal\Core\Routing\RequestContext;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\node\Plugin\Condition;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\node\Entity\NodeType;
 
class SettingsForm extends ConfigFormBase {
 
	/**
	* The path alias manager.
	*
	* @var \Drupal\Core\Path\AliasManagerInterface
	*/
	protected $aliasManager;

	/**
	* The path validator.
	*
	* @var \Drupal\Core\Path\PathValidatorInterface
	*/
	protected $pathValidator;

	/**
	* The request context.
	*
	* @var \Drupal\Core\Routing\RequestContext
	*/
	protected $requestContext;

	/**
	* Constructs a SiteInformationForm object.
	*
	* @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
	*   The factory for configuration objects.
	* @param \Drupal\Core\Path\AliasManagerInterface $alias_manager
	*   The path alias manager.
	* @param \Drupal\Core\Path\PathValidatorInterface $path_validator
	*   The path validator.
	* @param \Drupal\Core\Routing\RequestContext $request_context
	*   The request context.
	*/
	public function __construct(ConfigFactoryInterface $config_factory, AliasManagerInterface $alias_manager, PathValidatorInterface $path_validator, RequestContext $request_context) {
		parent::__construct($config_factory);
		$this->aliasManager = $alias_manager;
		$this->pathValidator = $path_validator;
		$this->requestContext = $request_context;
	}

	/**
	* {@inheritdoc}
	*/
	public static function create(ContainerInterface $container) {
		return new static(
			$container->get('config.factory'),
			$container->get('path.alias_manager'),
			$container->get('path.validator'),
			$container->get('router.request_context')
		);
	}
	/**
	* {@inheritdoc}
	*/

	public function getFormId() {
		return 'field_content_access_config_form';
	}
	
	/**
	* {@inheritdoc}
	*/

	protected function getEditableConfigNames() {
		return [
		'field_content_access.settings',
		];
	}
	/**
	* {@inheritdoc}
	*/
	public function buildForm(array $form, FormStateInterface $form_state) {
		$form = parent::buildForm($form, $form_state);
		$config = $this->config('field_content_access.settings');
		$form['restrict_roles']['restrict_tynt_roles'] = array(
			'#type'          => 'checkboxes',
			'#title'         => $this->t('Restrict Content Access for specific Role(s)'),
			'#default_value' => $config->get('restrict_tynt_roles'),
			'#options'       => user_role_names(),
			'#description'   => $this->t('Restrict Content Access only for the selected role(s). If none of the roles are selected, content will not be restricted. If a user has any of the roles checked, content will be restricted for that user.'),
		);
		$form['exclude_roles']['exclude_tynt_roles'] = array(
			'#type'          => 'checkboxes',
			'#title'         => $this->t('Exclude Content Access for specific Role(s)'),
			'#default_value' => $config->get('exclude_tynt_roles'),
			'#options'       => user_role_names(),
			'#description'   => $this->t('Exclude/do not Restrict Content Access for the selected role(s).'),
		);
		$form['content_type'] = array(
			'#type' => 'checkboxes',
			'#title' => $this->t('Restrict Content Access for specific Content Types'),
			'#default_value' => $config->get('content_type'),
			'#options' => node_type_get_names(),
			'#description' => t('Restrict Content Access only for the selected Content Types. If none of the types are selected, content will not be restricted. If any of type has selected, content will be restricted for that user.'), 

		);
		$restriction_fields = array();
		$restriction_fields["market_app"] = "Market Application";
		$restriction_fields["dist_hq"] = "Distributor HeadQuarter";
		$restriction_fields["region"] = "Region";
		$form['restricted_fields'] = array(
			'#title' => t('Restrict Content Access based on fields'),
			'#type' => 'checkboxes',
			'#default_value' => $config->get('restricted_fields'),
			'#options' => $restriction_fields,
			'#description' => t('Restrict Content Access only based on the selected field value.'),
		); 
		return $form;
	}

	/**
	* {@inheritdoc}
	*/

	public function submitForm(array &$form, FormStateInterface $form_state) {
		$config = $this->config('field_content_access.settings');
		$config->set('restrict_tynt_roles', $form_state->getValue('restrict_tynt_roles'));
		$config->set('exclude_tynt_roles', $form_state->getValue('exclude_tynt_roles'));
		$config->set('content_type', $form_state->getValue('content_type'));
		$config->set('restricted_fields', $form_state->getValue('restricted_fields'));
		$config->save();
		return parent::submitForm($form, $form_state);
	}
}